@@ -28,6 +28,8 @@ from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging
 
+from neutron.common import utils
+
 
 # Priorities - lower value is higher priority
 PRIORITY_NETWORK_CREATE = 0
@@ -87,6 +89,8 @@ class DhcpAgentNotifyAPI(object):
         self._plugin = plugin
         target = oslo_messaging.Target(topic=topic, version='1.0')
         self.client = n_rpc.get_client(target)
+        if not cfg.CONF.dhcp_agent_notification:
+            return
         # register callbacks for router interface changes
         registry.subscribe(self._after_router_interface_created,
                            resources.ROUTER_INTERFACE, events.AFTER_CREATE)
@@ -101,8 +105,6 @@ class DhcpAgentNotifyAPI(object):
             resources.SUBNET,
             resources.SUBNETS,
         )
-        if not cfg.CONF.dhcp_agent_notification:
-            return
         for resource in callback_resources:
             registry.subscribe(self._send_dhcp_notification,
                                resource, events.BEFORE_RESPONSE)
@@ -182,6 +184,7 @@ class DhcpAgentNotifyAPI(object):
     def _is_reserved_dhcp_port(self, port):
         return port.get('device_id') == constants.DEVICE_ID_RESERVED_DHCP_PORT
 
+    @utils.disable_notifications
     def _notify_agents(
             self, context, method, payload, network_id, network=None):
         """Notify all the agents that are hosting the network."""
@@ -242,12 +245,14 @@ class DhcpAgentNotifyAPI(object):
         self._cast_message(context, "port_create_end",
                            payload, agent.host, agent.topic)
 
+    @utils.disable_notifications
     def _cast_message(self, context, method, payload, host,
                       topic=topics.DHCP_AGENT):
         """Cast the payload to the dhcp agent running on the host."""
         cctxt = self.client.prepare(topic=topic, server=host)
         cctxt.cast(context, method, payload=payload)
 
+    @utils.disable_notifications
     def _fanout_message(self, context, method, payload):
         """Fanout the payload to all dhcp agents."""
         cctxt = self.client.prepare(fanout=True)
@@ -279,6 +284,7 @@ class DhcpAgentNotifyAPI(object):
         port = payload.metadata.get('port')
         self._notify_agents(payload.context, 'port_delete_end',
                             {'port_id': port['id'],
+                             'fixed_ips': port['fixed_ips'],
                              'network_id': port['network_id']},
                             port['network_id'])
 
@@ -298,26 +304,23 @@ class DhcpAgentNotifyAPI(object):
         method_name = '.'.join((resource, action, 'end'))
         data = {resource: payload.latest_state}
         if resource == resources.PORT and event == events.AFTER_UPDATE:
-            if self._only_status_changed(payload.states[0],
-                                         payload.latest_state):
+            if not self._notification_is_needed(payload.states[0],
+                                                payload.latest_state):
                 # don't waste time updating the DHCP agent for status updates
                 return
         self.notify(payload.context, data, method_name)
 
-    def _only_status_changed(self, orig, new):
-        # a status change will manifest as a bumped revision number, a new
-        # updated_at timestamp, and a new status. If that's all that changed,
-        # return True, else False
+    def _notification_is_needed(self, orig, new):
+        # notification to the DHCP agent should be send only if DHCP related
+        # attributes of the port were changed, like: fixed_ips, mac_address,
+        # extra_dhcp_opts, dns_name, dns_assignment or dns_domain.
+        # Otherwise there is no need to waste DHCP agent's time for doing
+        # updates.
         if not orig or not new:
-            return False
-        if set(orig.keys()) != set(new.keys()):
-            return False
-        for k in orig.keys():
-            if k in ('status', 'updated_at', 'revision_number'):
-                continue
-            if orig[k] != new[k]:
-                return False
-        return True
+            return True
+        return any(orig.get(k) != new.get(k) for k in (
+            'fixed_ips', 'mac_address', 'extra_dhcp_opts',
+            'dns_name', 'dns_assignment', 'dns_domain'))
 
     def _send_dhcp_notification(self, resource, event, trigger, payload=None):
         action = payload.action.split('_')[0]
