@@ -29,7 +29,6 @@ from neutron.tests.fullstack.resources import machine
 from neutron.tests.unit import testlib_api
 
 from neutron.agent.common import ovs_lib
-from neutron.services.qos.drivers.openvswitch import driver as ovs_drv
 
 
 load_tests = testlib_api.module_load_tests
@@ -201,47 +200,6 @@ class _TestBwLimitQoS(BaseQoSRuleTestCase):
         for direction in list(all_directions):
             self._wait_for_bw_rule_applied(vm, None, None, direction)
 
-    def test_bw_limit_qos_policy_rule_lifecycle(self):
-        new_limit = BANDWIDTH_LIMIT + 100
-
-        # Create port with qos policy attached
-        vm, qos_policy = self._prepare_vm_with_qos_policy(
-            [functools.partial(
-                self._add_bw_limit_rule,
-                BANDWIDTH_LIMIT, BANDWIDTH_BURST, self.direction)])
-        bw_rule = qos_policy['rules'][0]
-
-        self._wait_for_bw_rule_applied(
-            vm, BANDWIDTH_LIMIT, BANDWIDTH_BURST, self.direction)
-        qos_policy_id = qos_policy['id']
-
-        self.client.delete_bandwidth_limit_rule(bw_rule['id'], qos_policy_id)
-        self._wait_for_bw_rule_removed(vm, self.direction)
-
-        # Create new rule with no given burst value, in such case ovs and lb
-        # agent should apply burst value as
-        # bandwidth_limit * qos_consts.DEFAULT_BURST_RATE
-        new_expected_burst = self._get_expected_burst_value(new_limit,
-                                                            self.direction)
-        new_rule = self.safe_client.create_bandwidth_limit_rule(
-            self.tenant_id, qos_policy_id, new_limit, direction=self.direction)
-        self._wait_for_bw_rule_applied(
-            vm, new_limit, new_expected_burst, self.direction)
-
-        # Update qos policy rule id
-        self.client.update_bandwidth_limit_rule(
-            new_rule['id'], qos_policy_id,
-            body={'bandwidth_limit_rule': {'max_kbps': BANDWIDTH_LIMIT,
-                                           'max_burst_kbps': BANDWIDTH_BURST}})
-        self._wait_for_bw_rule_applied(
-            vm, BANDWIDTH_LIMIT, BANDWIDTH_BURST, self.direction)
-
-        # Remove qos policy from port
-        self.client.update_port(
-            vm.neutron_port['id'],
-            body={'port': {'qos_policy_id': None}})
-        self._wait_for_bw_rule_removed(vm, self.direction)
-
     def test_bw_limit_direction_change(self):
         # Create port with qos policy attached, with rule self.direction
         vm, qos_policy = self._prepare_vm_with_qos_policy(
@@ -584,27 +542,6 @@ class TestPacketRateLimitQoSOvs(_TestPacketRateLimitQoS,
     ]
 
 
-class TestQoSWithL2Population(base.BaseFullStackTestCase):
-    scenarios = [
-        (constants.AGENT_TYPE_OVS,
-         {'mech_drivers': 'openvswitch',
-          'supported_rules': ovs_drv.SUPPORTED_RULES}),
-    ]
-
-    def setUp(self):
-        host_desc = []  # No need to register agents for this test case
-        env_desc = environment.EnvironmentDescription(
-            qos=True, l2_pop=True, mech_drivers=self.mech_drivers)
-        env = environment.Environment(env_desc, host_desc)
-        super(TestQoSWithL2Population, self).setUp(env)
-
-    def test_supported_qos_rule_types(self):
-        res = self.client.list_qos_rule_types()
-        rule_types = {t['type'] for t in res['rule_types']}
-        expected_rules = set(self.supported_rules)
-        self.assertEqual(expected_rules, rule_types)
-
-
 class TestQoSPolicyIsDefault(base.BaseFullStackTestCase):
 
     NAME = 'fs_policy'
@@ -626,40 +563,34 @@ class TestQoSPolicyIsDefault(base.BaseFullStackTestCase):
         return self.client.update_qos_policy(
             qos_policy_id, body={'policy': {'is_default': is_default}})
 
-    def test_create_one_default_qos_policy_per_project(self):
+    def test_qos_policy_is_default(self):
+        # 1) Create one default QoS policy per project.
         project_ids = [uuidutils.generate_uuid(), uuidutils.generate_uuid()]
         for project_id in project_ids:
-            qos_policy = self._create_qos_policy(project_id, True)
-            self.assertTrue(qos_policy['is_default'])
-            self.assertEqual(project_id, qos_policy['project_id'])
-            qos_policy = self._create_qos_policy(project_id, False)
-            self.assertFalse(qos_policy['is_default'])
-            self.assertEqual(project_id, qos_policy['project_id'])
+            qos_policy1 = self._create_qos_policy(project_id, True)
+            self.assertTrue(qos_policy1['is_default'])
+            self.assertEqual(project_id, qos_policy1['project_id'])
+            qos_policy2 = self._create_qos_policy(project_id, False)
+            self.assertFalse(qos_policy2['is_default'])
+            self.assertEqual(project_id, qos_policy2['project_id'])
 
-    def test_create_two_default_qos_policies_per_project(self):
-        project_id = uuidutils.generate_uuid()
-        qos_policy = self._create_qos_policy(project_id, True)
-        self.assertTrue(qos_policy['is_default'])
-        self.assertEqual(project_id, qos_policy['project_id'])
+        # 2) Try to add a second default policy to the first project, that has
+        # already one QoS default policy
         self.assertRaises(exceptions.Conflict,
-                          self._create_qos_policy, project_id, True)
+                          self._create_qos_policy, project_ids[0], True)
 
-    def test_update_default_status(self):
-        project_ids = [uuidutils.generate_uuid(), uuidutils.generate_uuid()]
-        for project_id in project_ids:
-            qos_policy = self._create_qos_policy(project_id, True)
-            self.assertTrue(qos_policy['is_default'])
-            qos_policy = self._update_qos_policy(qos_policy['id'], False)
-            self.assertFalse(qos_policy['policy']['is_default'])
+        # 3) Update default status of a QoS policy.
+        qos_policy1 = self._update_qos_policy(qos_policy1['id'], False)
+        self.assertFalse(qos_policy1['policy']['is_default'])
+        qos_policy2 = self._update_qos_policy(qos_policy2['id'], True)
+        self.assertTrue(qos_policy2['policy']['is_default'])
 
-    def test_update_default_status_conflict(self):
-        project_id = uuidutils.generate_uuid()
-        qos_policy_1 = self._create_qos_policy(project_id, True)
-        self.assertTrue(qos_policy_1['is_default'])
-        qos_policy_2 = self._create_qos_policy(project_id, False)
-        self.assertFalse(qos_policy_2['is_default'])
+        # 4) Try to update the QoS policy status if a default QoS policy
+        # already exists in this project.
+        qos_policy_3 = self._create_qos_policy(project_ids[1], False)
+        self.assertFalse(qos_policy_3['is_default'])
         self.assertRaises(exceptions.Conflict,
-                          self._update_qos_policy, qos_policy_2['id'], True)
+                          self._update_qos_policy, qos_policy_3['id'], True)
 
 
 class _TestMinBwQoS(BaseQoSRuleTestCase):
