@@ -69,6 +69,16 @@ class SystemAdminTests(FloatingIPAPITestCase):
             policy.enforce,
             self.context, "get_floatingip", self.alt_target)
 
+    def test_get_floatingips_tags(self):
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, "get_floatingips_tags", self.target)
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, "get_floatingips_tags", self.alt_target)
+
     def test_update_floatingip(self):
         self.assertRaises(
             base_policy.InvalidScope,
@@ -79,6 +89,16 @@ class SystemAdminTests(FloatingIPAPITestCase):
             policy.enforce,
             self.context, "update_floatingip", self.alt_target)
 
+    def test_update_floatingips_tags(self):
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, "update_floatingips_tags", self.target)
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, "update_floatingips_tags", self.alt_target)
+
     def test_delete_floatingip(self):
         self.assertRaises(
             base_policy.InvalidScope,
@@ -104,12 +124,68 @@ class SystemReaderTests(SystemMemberTests):
         self.context = self.system_reader_ctx
 
 
-class ProjectAdminTests(FloatingIPAPITestCase):
+class AdminTests(FloatingIPAPITestCase):
 
     def setUp(self):
-        super(ProjectAdminTests, self).setUp()
+        super(AdminTests, self).setUp()
         self.context = self.project_admin_ctx
 
+    def test_create_floatingip(self):
+        self.assertTrue(
+            policy.enforce(self.context, "create_floatingip", self.target))
+        self.assertTrue(
+            policy.enforce(self.context, "create_floatingip", self.alt_target))
+
+    def test_create_floatingip_with_ip_address(self):
+        self.assertTrue(
+            policy.enforce(
+                self.context,
+                "create_floatingip:floating_ip_address", self.target))
+        self.assertTrue(
+            policy.enforce(
+                self.context,
+                "create_floatingip:floating_ip_address", self.alt_target))
+
+    def test_get_floatingip(self):
+        self.assertTrue(
+            policy.enforce(self.context, "get_floatingip", self.target))
+        self.assertTrue(
+            policy.enforce(self.context, "get_floatingip", self.alt_target))
+
+    def test_get_floatingips_tags(self):
+        self.assertTrue(
+            policy.enforce(self.context, "get_floatingips_tags", self.target))
+        self.assertTrue(
+            policy.enforce(self.context, "get_floatingips_tags",
+                           self.alt_target))
+
+    def test_update_floatingip(self):
+        self.assertTrue(
+            policy.enforce(self.context, "update_floatingip", self.target))
+        self.assertTrue(
+            policy.enforce(self.context, "update_floatingip", self.alt_target))
+
+    def test_update_floatingips_tags(self):
+        self.assertTrue(
+            policy.enforce(self.context, "update_floatingips_tags",
+                           self.target))
+        self.assertTrue(
+            policy.enforce(self.context, "update_floatingips_tags",
+                           self.alt_target))
+
+    def test_delete_floatingip(self):
+        self.assertTrue(
+            policy.enforce(self.context, "delete_floatingip", self.target))
+        self.assertTrue(
+            policy.enforce(self.context, "delete_floatingip", self.alt_target))
+
+
+class ProjectMemberTests(AdminTests):
+
+    def setUp(self):
+        super(ProjectMemberTests, self).setUp()
+        self.context = self.project_member_ctx
+
     def test_create_floatingip(self):
         self.assertTrue(
             policy.enforce(self.context, "create_floatingip", self.target))
@@ -119,10 +195,11 @@ class ProjectAdminTests(FloatingIPAPITestCase):
             self.context, "create_floatingip", self.alt_target)
 
     def test_create_floatingip_with_ip_address(self):
-        self.assertTrue(
-            policy.enforce(
-                self.context,
-                "create_floatingip:floating_ip_address", self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, "create_floatingip:floating_ip_address",
+            self.target)
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
             policy.enforce,
@@ -136,6 +213,14 @@ class ProjectAdminTests(FloatingIPAPITestCase):
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, "get_floatingip", self.alt_target)
 
+    def test_get_floatingips_tags(self):
+        self.assertTrue(
+            policy.enforce(self.context, "get_floatingips_tags", self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, "get_floatingips_tags",
+            self.alt_target)
+
     def test_update_floatingip(self):
         self.assertTrue(
             policy.enforce(self.context, "update_floatingip", self.target))
@@ -143,6 +228,15 @@ class ProjectAdminTests(FloatingIPAPITestCase):
             base_policy.PolicyNotAuthorized,
             policy.enforce, self.context, "update_floatingip", self.alt_target)
 
+    def test_update_floatingips_tags(self):
+        self.assertTrue(
+            policy.enforce(self.context, "update_floatingips_tags",
+                           self.target))
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce, self.context, "update_floatingips_tags",
+            self.alt_target)
+
     def test_delete_floatingip(self):
         self.assertTrue(
             policy.enforce(self.context, "delete_floatingip", self.target))
@@ -151,25 +245,6 @@ class ProjectAdminTests(FloatingIPAPITestCase):
             policy.enforce, self.context, "delete_floatingip", self.alt_target)
 
 
-class ProjectMemberTests(ProjectAdminTests):
-
-    def setUp(self):
-        super(ProjectMemberTests, self).setUp()
-        self.context = self.project_member_ctx
-
-    def test_create_floatingip_with_ip_address(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, "create_floatingip:floating_ip_address",
-            self.target)
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, "create_floatingip:floating_ip_address",
-            self.alt_target)
-
-
 class ProjectReaderTests(ProjectMemberTests):
 
     def setUp(self):
@@ -196,6 +271,16 @@ class ProjectReaderTests(ProjectMemberTests):
             policy.enforce,
             self.context, "update_floatingip", self.alt_target)
 
+    def test_update_floatingips_tags(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, "update_floatingips_tags", self.target)
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, "update_floatingips_tags", self.alt_target)
+
     def test_delete_floatingip(self):
         self.assertRaises(
             base_policy.PolicyNotAuthorized,
