@@ -32,65 +32,6 @@ class SystemAdminTests(NetworkSegmentRangeAPITestCase):
         super(SystemAdminTests, self).setUp()
         self.context = self.system_admin_ctx
 
-    def test_create_network_segment_range(self):
-        self.assertTrue(
-            policy.enforce(self.context,
-                           'create_network_segment_range', self.target))
-
-    def test_get_network_segment_range(self):
-        self.assertTrue(
-            policy.enforce(self.context,
-                           'get_network_segment_range', self.target))
-
-    def test_update_network_segment_range(self):
-        self.assertTrue(
-            policy.enforce(self.context,
-                           'update_network_segment_range', self.target))
-
-    def test_delete_network_segment_range(self):
-        self.assertTrue(
-            policy.enforce(self.context,
-                           'delete_network_segment_range', self.target))
-
-
-class SystemMemberTests(SystemAdminTests):
-
-    def setUp(self):
-        super(SystemMemberTests, self).setUp()
-        self.context = self.system_member_ctx
-
-    def test_create_network_segment_range(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'create_network_segment_range', self.target)
-
-    def test_update_network_segment_range(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'update_network_segment_range', self.target)
-
-    def test_delete_network_segment_range(self):
-        self.assertRaises(
-            base_policy.PolicyNotAuthorized,
-            policy.enforce,
-            self.context, 'delete_network_segment_range', self.target)
-
-
-class SystemReaderTests(SystemMemberTests):
-
-    def setUp(self):
-        super(SystemReaderTests, self).setUp()
-        self.context = self.system_reader_ctx
-
-
-class ProjectAdminTests(NetworkSegmentRangeAPITestCase):
-
-    def setUp(self):
-        super(ProjectAdminTests, self).setUp()
-        self.context = self.project_admin_ctx
-
     def test_create_network_segment_range(self):
         self.assertRaises(
             base_policy.InvalidScope,
@@ -103,25 +44,141 @@ class ProjectAdminTests(NetworkSegmentRangeAPITestCase):
             policy.enforce,
             self.context, 'get_network_segment_range', self.target)
 
+    def test_get_network_segment_ranges_tags(self):
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, 'get_network_segment_ranges_tags', self.target)
+
     def test_update_network_segment_range(self):
         self.assertRaises(
             base_policy.InvalidScope,
             policy.enforce,
             self.context, 'update_network_segment_range', self.target)
 
+    def test_update_network_segment_ranges_tags(self):
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, 'update_network_segment_ranges_tags', self.target)
+
     def test_delete_network_segment_range(self):
         self.assertRaises(
             base_policy.InvalidScope,
             policy.enforce,
             self.context, 'delete_network_segment_range', self.target)
 
+    def test_delete_network_segment_ranges_tags(self):
+        self.assertRaises(
+            base_policy.InvalidScope,
+            policy.enforce,
+            self.context, 'delete_network_segment_ranges_tags', self.target)
 
-class ProjectMemberTests(ProjectAdminTests):
+
+class SystemMemberTests(SystemAdminTests):
+
+    def setUp(self):
+        super(SystemMemberTests, self).setUp()
+        self.context = self.system_member_ctx
+
+
+class SystemReaderTests(SystemMemberTests):
+
+    def setUp(self):
+        super(SystemReaderTests, self).setUp()
+        self.context = self.system_reader_ctx
+
+
+class AdminTests(NetworkSegmentRangeAPITestCase):
+
+    def setUp(self):
+        super(AdminTests, self).setUp()
+        self.context = self.project_admin_ctx
+
+    def test_create_network_segment_range(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'create_network_segment_range', self.target))
+
+    def test_get_network_segment_range(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'get_network_segment_range', self.target))
+
+    def test_get_network_segment_ranges_tags(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'get_network_segment_ranges_tags', self.target))
+
+    def test_update_network_segment_range(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_network_segment_range', self.target))
+
+    def test_update_network_segment_ranges_tags(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'update_network_segment_ranges_tags', self.target))
+
+    def test_delete_network_segment_range(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'delete_network_segment_range', self.target))
+
+    def test_delete_network_segment_ranges_tags(self):
+        self.assertTrue(
+            policy.enforce(self.context,
+                           'delete_network_segment_ranges_tags', self.target))
+
+
+class ProjectMemberTests(AdminTests):
 
     def setUp(self):
         super(ProjectMemberTests, self).setUp()
         self.context = self.project_member_ctx
 
+    def test_create_network_segment_range(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'create_network_segment_range', self.target)
+
+    def test_get_network_segment_range(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'get_network_segment_range', self.target)
+
+    def test_get_network_segment_ranges_tags(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'get_network_segment_ranges_tags', self.target)
+
+    def test_update_network_segment_range(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_network_segment_range', self.target)
+
+    def test_update_network_segment_ranges_tags(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'update_network_segment_ranges_tags', self.target)
+
+    def test_delete_network_segment_range(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'delete_network_segment_range', self.target)
+
+    def test_delete_network_segment_ranges_tags(self):
+        self.assertRaises(
+            base_policy.PolicyNotAuthorized,
+            policy.enforce,
+            self.context, 'delete_network_segment_ranges_tags', self.target)
+
 
 class ProjectReaderTests(ProjectMemberTests):
 
